@@ -3,7 +3,6 @@ package AWS::XRay;
 use 5.012000;
 use strict;
 use warnings;
-use parent qw/Class::Data::Inheritable/;
 
 use Crypt::URandom ();
 use IO::Socket::INET;
@@ -11,23 +10,26 @@ use Time::HiRes ();
 use AWS::XRay::Segment;
 
 use Exporter 'import';
-our @EXPORT_OK = qw/ new_trace_id trace /;
+our @EXPORT_OK = qw/ new_trace_id capture capture_from trace /;
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 our $TRACE_ID;
 our $SEGMENT_ID;
 our $ENABLED = 1;
+our $DAEMON_HOST = "127.0.0.1";
+our $DAEMON_PORT = 2000;
+
+if ($ENV{"AWS_XRAY_DAEMON_ADDRESS"}) {
+    ($DAEMON_HOST, $DAEMON_PORT) = split /:/, $ENV{"AWS_XRAY_DAEMON_ADDRESS"};
+}
 
 my $Sock;
 
-__PACKAGE__->mk_classdata( daemon_host => "127.0.0.1" );
-__PACKAGE__->mk_classdata( daemon_port => "127.0.0.1" );
-
 sub sock {
     $Sock //= IO::Socket::INET->new(
-        PeerAddr => __PACKAGE__->daemon_host,
-        PeerPort => __PACKAGE__->daemon_port,
+        PeerAddr => $DAEMON_HOST || "127.0.0.1",
+        PeerPort => $DAEMON_PORT || 2000,
         Proto    => "udp",
     );
 }
@@ -44,9 +46,11 @@ sub new_id {
     unpack("H*", Crypt::URandom::urandom(8))
 }
 
-sub trace ($&) {
-    my ($name, $code) = @_;
+# alias for backward compatibility
+*trace = \&capture;
 
+sub capture {
+    my ($name, $code) = @_;
     return $code->(AWS::XRay::Segment->new) if !$ENABLED;
 
     local $AWS::XRay::TRACE_ID = $AWS::XRay::TRACE_ID // new_trace_id();
@@ -77,7 +81,7 @@ sub trace ($&) {
         };
     }
     eval {
-        $segment->send();
+        $segment->close();
     };
     if ($@) {
         warn $@;
@@ -86,6 +90,25 @@ sub trace ($&) {
     return wantarray ? @ret : $ret[0];
 }
 
+sub capture_from {
+    my ($header, $name, $code) = @_;
+    local($AWS::XRay::TRACE_ID, $AWS::XRay::SEGMENT_ID) = parse_trace_header($header);
+    capture($name, $code);
+}
+
+sub parse_trace_header {
+    my $header = shift or return;
+
+    my ($trace_id, $segment_id);
+    if ($header =~ /Root=([0-9a-fA-F-]+)/) {
+        $trace_id = $1;
+    }
+    if ($header =~ /Parent=([0-9a-fA-F]+)/) {
+        $segment_id = $1;
+    }
+    return ($trace_id, $segment_id);
+}
+
 1;
 __END__
 
@@ -97,16 +120,16 @@ AWS::XRay - AWS X-Ray tracing library
 
 =head1 SYNOPSIS
 
-    use AWS::XRay qw/ trace /;
+    use AWS::XRay qw/ capture /;
 
-    trace "myApp", sub {
-        trace "remote", sub {
+    capture "myApp", sub {
+        capture "remote", sub {
             # do something ...
-            trace "nested", sub {
+            capture "nested", sub {
                 # ...
             };
         };
-        trace "myHTTP", sub {
+        capture "myHTTP", sub {
             my $segment = shift;
             # ...
             $segment->{http} = { # modify segument document
@@ -121,6 +144,16 @@ AWS::XRay - AWS X-Ray tracing library
         };
     };
 
+    my $header;
+    capture "source", sub {
+        my $segment = shift;
+        $header = $segment->trace_header;
+    };
+    capture_from $header, "dest", sub {
+        my $segment = shift;  # is a child of "source" segment
+        # ...
+    };
+
 =head1 DESCRIPTION
 
 AWS::XRay is a tracing library with AWS X-Ray.
@@ -135,33 +168,37 @@ Generate a Trace ID. (e.g. "1-581cf771-a006649127e371903a2de979")
 
 L<Document|https://docs.aws.amazon.com/xray/latest/devguide/xray-api-sendingdata.html#xray-api-traceids>
 
-=head2 trace($name, $code)
+=head2 capture($name, $code)
 
-trace() executes $code->($segment) and send the segment document to X-Ray daemon.
+capture() executes $code->($segment) and send the segment document to X-Ray daemon.
 
 $segment is a AWS::XRay::Segment object.
 
 When $AWS::XRay::TRACE_ID is not set, generates TRACE_ID automatically.
 
-When trace() called in parent trace(), $segment is a sub segment document.
+When capture() called from other capture(), $segment is a sub segment document.
 
 See also L<AWS X-Ray Segment Documents|https://docs.aws.amazon.com/xray/latest/devguide/xray-api-segmentdocuments.html>.
 
-=head2 daemon_host
+=head2 capture_from($header, $name, $code)
 
-Set a address for X-Ray daemon. defult "127.0.0.1".
+capture_from() parses the trace header and capture the $code with sub segment of header's segment.
 
-    AWS::XRay->daemon_host("example.com");
+=head2 parse_trace_header($header)
 
-=head2 daemon_port
+    my ($trace_id, $segment_id) = parse_trace_header($header);
 
-Set a UDP port number for X-Ray daemon. defult 2000.
+Parse a trace header (e.g. "Root=1-5759e988-bd862e3fe1be46a994272793;Parent=53995c3f42cd8ad8").
 
-    AWS::XRay->daemon_port(2002);
+=head1 CONFIGURATION
 
 =head2 $AWS::XRay::Enabled
 
-Default true. When set false, trace() executes sub but do not send segument documents to X-Ray daemon.
+Default true. When set false, capture() executes sub but do not send segument documents to X-Ray daemon.
+
+=head2 AWS_XRAY_DAEMON_ADDRESS environment variable
+
+Set the host and port of the X-Ray daemon. Default 127.0.0.1:2000
 
 =head1 LICENSE
 
